#!/bin/sh

cat << EOF
global:
  # The smarthost and SMTP sender used for mail notifications.
  smtp_smarthost: '${SMTP_SMARTHOST:?}'
  smtp_from: '${SMTP_FROM:?}'
  smtp_auth_username: '${SMTP_USER:?}'
  smtp_auth_password: '${SMTP_PASSWORD}'

# The root route on which each incoming alert enters.
route:
  # The labels by which incoming alerts are grouped together. For example,
  # multiple alerts coming in for cluster=A and alertname=LatencyHigh would
  # be batched into a single group.
  group_by: ['alertname', 'cluster', 'service']

  # When a new group of alerts is created by an incoming alert, wait at
  # least 'group_wait' to send the initial notification.
  # This way ensures that you get multiple alerts for the same group that start
  # firing shortly after another are batched together on the first 
  # notification.
  group_wait: 30s

  # When the first notification was sent, wait 'group_interval' to send a batch
  # of new alerts that started firing for that group.
  group_interval: 5m

  # If an alert has successfully been sent, wait 'repeat_interval' to
  # resend them.
  repeat_interval: ${REPEAT_INTERVAL:?}

  # A default receiver
  receiver: admins

  # All the above attributes are inherited by all child routes and can 
  # overwritten on each.

  # The child route trees.
  routes: []


# Inhibition rules allow to mute a set of alerts given that another alert is
# firing.
# We use this to mute any warning-level notifications if the same alert is 
# already critical.
inhibit_rules:
- source_match:
    severity: 'critical'
  target_match:
    severity: 'warning'
  # Apply inhibition if the alertname is the same.
  equal: ['alertname', 'cluster', 'service']


receivers:
- name: 'admins'
EOF

if [ -n "$RECEIVER_EMAIL" ]; then
	cat << EOF
  email_configs:
  - to: '$RECEIVER_EMAIL'
    send_resolved: true
EOF
fi

if [ -n "$RECEIVER_WEBHOOK" ]; then
	cat << EOF
  webhook_configs:
  - url: ${RECEIVER_WEBHOOK:?}
EOF
fi
